basico package
==============

.. automodule:: basico
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

basico.biomodels module
-----------------------

.. automodule:: basico.biomodels
   :members:
   :undoc-members:
   :show-inheritance:

basico.compartment\_array\_tools module
---------------------------------------

.. automodule:: basico.compartment_array_tools
   :members:
   :undoc-members:
   :show-inheritance:

basico.jws\_online module
-------------------------

.. automodule:: basico.jws_online
   :members:
   :undoc-members:
   :show-inheritance:

basico.model\_info module
-------------------------

.. automodule:: basico.model_info
   :members:
   :undoc-members:
   :show-inheritance:

basico.model\_io module
-----------------------

.. automodule:: basico.model_io
   :members:
   :undoc-members:
   :show-inheritance:

basico.task\_parameterestimation module
---------------------------------------

.. automodule:: basico.task_parameterestimation
   :members:
   :undoc-members:
   :show-inheritance:

basico.task\_steadystate module
-------------------------------

.. automodule:: basico.task_steadystate
   :members:
   :undoc-members:
   :show-inheritance:

basico.task\_timecourse module
------------------------------

.. automodule:: basico.task_timecourse
   :members:
   :undoc-members:
   :show-inheritance:

basico.task\_scan module
------------------------------

.. automodule:: basico.task_scan
   :members:
   :undoc-members:
   :show-inheritance:


basico.task\_optimization module
------------------------------

.. automodule:: basico.task_optimization
   :members:
   :undoc-members:
   :show-inheritance:

basico.task\_sensitivities module
------------------------------

.. automodule:: basico.task_sensitivities
   :members:
   :undoc-members:
   :show-inheritance:
